#ifndef __DOLFIN_PLOT_H
#define __DOLFIN_PLOT_H

// DOLFIN plot interface

#include <dolfin/plot/plot.h>
#include <dolfin/plot/VTKPlotter.h>

#endif
